==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderMapperEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapIdentityProviderMapperEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setId((String) value);
        }
    },
    CONFIG {
        public static final String FIELD_NAME = "Config";
        public static final String FIELD_NAME_DASHED = "config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (java.util.Map<String,String>) e.getConfig();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setConfig((java.util.Map<String,String>) value);
        }
    },
    IDENTITY_PROVIDER_ALIAS {
        public static final String FIELD_NAME = "IdentityProviderAlias";
        public static final String FIELD_NAME_DASHED = "identity-provider-alias";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (String) e.getIdentityProviderAlias();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setIdentityProviderAlias((String) value);
        }
    },
    IDENTITY_PROVIDER_MAPPER {
        public static final String FIELD_NAME = "IdentityProviderMapper";
        public static final String FIELD_NAME_DASHED = "identity-provider-mapper";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (String) e.getIdentityProviderMapper();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setIdentityProviderMapper((String) value);
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (String) e.getName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setName((String) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderMapperEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapIdentityProviderMapperEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (String) e.getId();
        }
    },
    CONFIG {
        public static final String FIELD_NAME = "Config";
        public static final String FIELD_NAME_DASHED = "config";
        public static final String FIELD_NAME_CAMEL_CASE = "config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setConfig((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (java.util.Map<String,String>) e.getConfig();
        }
    },
    IDENTITY_PROVIDER_ALIAS {
        public static final String FIELD_NAME = "IdentityProviderAlias";
        public static final String FIELD_NAME_DASHED = "identity-provider-alias";
        public static final String FIELD_NAME_CAMEL_CASE = "identityProviderAlias";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setIdentityProviderAlias((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (String) e.getIdentityProviderAlias();
        }
    },
    IDENTITY_PROVIDER_MAPPER {
        public static final String FIELD_NAME = "IdentityProviderMapper";
        public static final String FIELD_NAME_DASHED = "identity-provider-mapper";
        public static final String FIELD_NAME_CAMEL_CASE = "identityProviderMapper";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setIdentityProviderMapper((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (String) e.getIdentityProviderMapper();
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        public static final String FIELD_NAME_CAMEL_CASE = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e, T value) {
            e.setName((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity e) {
            return (String) e.getName();
        }
    },
}
